@@ -3,7 +3,7 @@
  * HISTOGRAM.C -  Icinga Alert Histogram CGI
  *
  * Copyright (c) 1999-2009 Ethan Galstad (egalstad@nagios.org)
- * Copyright (c) 2009-2013 Icinga Development Team (http://www.icinga.org)
+ * Copyright (c) 2009-2014 Icinga Development Team (http://www.icinga.org)
  *
  * License:
  *
@@ -893,27 +893,38 @@ int main(int argc, char **argv) {
 
 int process_cgivars(void) {
 	char **variables;
+	char *key = NULL;
+	char *value = NULL;
 	char *temp_buffer = NULL;
 	int error = FALSE;
 	int x;
 
 	variables = getcgivars();
 
-	for (x = 0; variables[x] != NULL; x++) {
+	for (x = 0; variables[x] != NULL; x+=2) {
+		key = variables[x];
+		value = variables[x+1];
 
 		/* do some basic length checking on the variable identifier to prevent buffer overflows */
-		if (strlen(variables[x]) >= MAX_INPUT_BUFFER - 1)
-			continue;
+		if (strlen(key) >= MAX_INPUT_BUFFER - 1) {
+			error = TRUE;
+			break;
+		}
+		/* likewise, check the value for length if it exists */
+		if (key != NULL)
+			if (strlen(key) >= MAX_INPUT_BUFFER - 1) {
+				error = TRUE;
+				break;
+		}
 
 		/* we found the host argument */
-		else if (!strcmp(variables[x], "host")) {
-			x++;
-			if (variables[x] == NULL) {
+		if (!strcmp(key, "host")) {
+			if (value == NULL) {
 				error = TRUE;
 				break;
 			}
 
-			if ((host_name = (char *)strdup(variables[x])) == NULL)
+			if ((host_name = (char *)strdup(value)) == NULL)
 				host_name = "";
 			strip_html_brackets(host_name);
 
@@ -921,14 +932,13 @@ int process_cgivars(void) {
 		}
 
 		/* we found the node width argument */
-		else if (!strcmp(variables[x], "service")) {
-			x++;
-			if (variables[x] == NULL) {
+		else if (!strcmp(key, "service")) {
+			if (value == NULL) {
 				error = TRUE;
 				break;
 			}
 
-			if ((service_desc = (char *)strdup(variables[x])) == NULL)
+			if ((service_desc = (char *)strdup(value)) == NULL)
 				service_desc = "";
 			strip_html_brackets(service_desc);
 
@@ -936,14 +946,13 @@ int process_cgivars(void) {
 		}
 
 		/* we found a combined host/service */
-		else if (!strcmp(variables[x], "hostservice")) {
-			x++;
-			if (variables[x] == NULL) {
+		else if (!strcmp(key, "hostservice")) {
+			if (value == NULL) {
 				error = TRUE;
 				break;
 			}
 
-			temp_buffer = strtok(variables[x], "^");
+			temp_buffer = strtok(value, "^");
 
 			if ((host_name = (char *)strdup(temp_buffer)) == NULL)
 				host_name = "";
@@ -961,43 +970,40 @@ int process_cgivars(void) {
 		}
 
 		/* we found first time argument */
-		else if (!strcmp(variables[x], "t1")) {
-			x++;
-			if (variables[x] == NULL) {
+		else if (!strcmp(key, "t1")) {
+			if (value == NULL) {
 				error = TRUE;
 				break;
 			}
 
-			t1 = (time_t)strtoul(variables[x], NULL, 10);
+			t1 = (time_t)strtoul(value, NULL, 10);
 			timeperiod_type = TIMEPERIOD_CUSTOM;
 		}
 
 		/* we found first time argument */
-		else if (!strcmp(variables[x], "t2")) {
-			x++;
-			if (variables[x] == NULL) {
+		else if (!strcmp(key, "t2")) {
+			if (value == NULL) {
 				error = TRUE;
 				break;
 			}
 
-			t2 = (time_t)strtoul(variables[x], NULL, 10);
+			t2 = (time_t)strtoul(value, NULL, 10);
 			timeperiod_type = TIMEPERIOD_CUSTOM;
 		}
 
 		/* we found the image creation option */
-		else if (!strcmp(variables[x], "createimage")) {
+		else if (!strcmp(key, "createimage")) {
 			content_type = IMAGE_CONTENT;
 		}
 
 		/* we found the backtrack archives argument */
-		else if (!strcmp(variables[x], "backtrack")) {
-			x++;
-			if (variables[x] == NULL) {
+		else if (!strcmp(key, "backtrack")) {
+			if (value == NULL) {
 				error = TRUE;
 				break;
 			}
 
-			backtrack_archives = atoi(variables[x]);
+			backtrack_archives = atoi(value);
 			if (backtrack_archives < 0)
 				backtrack_archives = 0;
 			if (backtrack_archives > MAX_ARCHIVE_BACKTRACKS)
@@ -1005,40 +1011,39 @@ int process_cgivars(void) {
 		}
 
 		/* we found the standard timeperiod argument */
-		else if (!strcmp(variables[x], "timeperiod")) {
-			x++;
-			if (variables[x] == NULL) {
+		else if (!strcmp(key, "timeperiod")) {
+			if (value == NULL) {
 				error = TRUE;
 				break;
 			}
 
-			if (!strcmp(variables[x], "today"))
+			if (!strcmp(value, "today"))
 				timeperiod_type = TIMEPERIOD_TODAY;
-			else if (!strcmp(variables[x], "yesterday"))
+			else if (!strcmp(value, "yesterday"))
 				timeperiod_type = TIMEPERIOD_YESTERDAY;
-			else if (!strcmp(variables[x], "thisweek"))
+			else if (!strcmp(value, "thisweek"))
 				timeperiod_type = TIMEPERIOD_THISWEEK;
-			else if (!strcmp(variables[x], "lastweek"))
+			else if (!strcmp(value, "lastweek"))
 				timeperiod_type = TIMEPERIOD_LASTWEEK;
-			else if (!strcmp(variables[x], "thismonth"))
+			else if (!strcmp(value, "thismonth"))
 				timeperiod_type = TIMEPERIOD_THISMONTH;
-			else if (!strcmp(variables[x], "lastmonth"))
+			else if (!strcmp(value, "lastmonth"))
 				timeperiod_type = TIMEPERIOD_LASTMONTH;
-			else if (!strcmp(variables[x], "thisquarter"))
+			else if (!strcmp(value, "thisquarter"))
 				timeperiod_type = TIMEPERIOD_THISQUARTER;
-			else if (!strcmp(variables[x], "lastquarter"))
+			else if (!strcmp(value, "lastquarter"))
 				timeperiod_type = TIMEPERIOD_LASTQUARTER;
-			else if (!strcmp(variables[x], "thisyear"))
+			else if (!strcmp(value, "thisyear"))
 				timeperiod_type = TIMEPERIOD_THISYEAR;
-			else if (!strcmp(variables[x], "lastyear"))
+			else if (!strcmp(value, "lastyear"))
 				timeperiod_type = TIMEPERIOD_LASTYEAR;
-			else if (!strcmp(variables[x], "last24hours"))
+			else if (!strcmp(value, "last24hours"))
 				timeperiod_type = TIMEPERIOD_LAST24HOURS;
-			else if (!strcmp(variables[x], "last7days"))
+			else if (!strcmp(value, "last7days"))
 				timeperiod_type = TIMEPERIOD_LAST7DAYS;
-			else if (!strcmp(variables[x], "last31days"))
+			else if (!strcmp(value, "last31days"))
 				timeperiod_type = TIMEPERIOD_LAST31DAYS;
-			else if (!strcmp(variables[x], "custom"))
+			else if (!strcmp(value, "custom"))
 				timeperiod_type = TIMEPERIOD_CUSTOM;
 			else
 				timeperiod_type = TIMEPERIOD_TODAY;
@@ -1049,9 +1054,8 @@ int process_cgivars(void) {
 		}
 
 		/* we found time argument */
-		else if (!strcmp(variables[x], "smon")) {
-			x++;
-			if (variables[x] == NULL) {
+		else if (!strcmp(key, "smon")) {
+			if (value == NULL) {
 				error = TRUE;
 				break;
 			}
@@ -1059,15 +1063,14 @@ int process_cgivars(void) {
 			if (timeperiod_type != TIMEPERIOD_CUSTOM)
 				continue;
 
-			start_month = atoi(variables[x]);
+			start_month = atoi(value);
 			timeperiod_type = TIMEPERIOD_CUSTOM;
 			compute_time_from_parts = TRUE;
 		}
 
 		/* we found time argument */
-		else if (!strcmp(variables[x], "sday")) {
-			x++;
-			if (variables[x] == NULL) {
+		else if (!strcmp(key, "sday")) {
+			if (value == NULL) {
 				error = TRUE;
 				break;
 			}
@@ -1075,15 +1078,14 @@ int process_cgivars(void) {
 			if (timeperiod_type != TIMEPERIOD_CUSTOM)
 				continue;
 
-			start_day = atoi(variables[x]);
+			start_day = atoi(value);
 			timeperiod_type = TIMEPERIOD_CUSTOM;
 			compute_time_from_parts = TRUE;
 		}
 
 		/* we found time argument */
-		else if (!strcmp(variables[x], "syear")) {
-			x++;
-			if (variables[x] == NULL) {
+		else if (!strcmp(key, "syear")) {
+			if (value == NULL) {
 				error = TRUE;
 				break;
 			}
@@ -1091,15 +1093,14 @@ int process_cgivars(void) {
 			if (timeperiod_type != TIMEPERIOD_CUSTOM)
 				continue;
 
-			start_year = atoi(variables[x]);
+			start_year = atoi(value);
 			timeperiod_type = TIMEPERIOD_CUSTOM;
 			compute_time_from_parts = TRUE;
 		}
 
 		/* we found time argument */
-		else if (!strcmp(variables[x], "smin")) {
-			x++;
-			if (variables[x] == NULL) {
+		else if (!strcmp(key, "smin")) {
+			if (value == NULL) {
 				error = TRUE;
 				break;
 			}
@@ -1107,15 +1108,14 @@ int process_cgivars(void) {
 			if (timeperiod_type != TIMEPERIOD_CUSTOM)
 				continue;
 
-			start_minute = atoi(variables[x]);
+			start_minute = atoi(value);
 			timeperiod_type = TIMEPERIOD_CUSTOM;
 			compute_time_from_parts = TRUE;
 		}
 
 		/* we found time argument */
-		else if (!strcmp(variables[x], "ssec")) {
-			x++;
-			if (variables[x] == NULL) {
+		else if (!strcmp(key, "ssec")) {
+			if (value == NULL) {
 				error = TRUE;
 				break;
 			}
@@ -1123,15 +1123,14 @@ int process_cgivars(void) {
 			if (timeperiod_type != TIMEPERIOD_CUSTOM)
 				continue;
 
-			start_second = atoi(variables[x]);
+			start_second = atoi(value);
 			timeperiod_type = TIMEPERIOD_CUSTOM;
 			compute_time_from_parts = TRUE;
 		}
 
 		/* we found time argument */
-		else if (!strcmp(variables[x], "shour")) {
-			x++;
-			if (variables[x] == NULL) {
+		else if (!strcmp(key, "shour")) {
+			if (value == NULL) {
 				error = TRUE;
 				break;
 			}
@@ -1139,16 +1138,15 @@ int process_cgivars(void) {
 			if (timeperiod_type != TIMEPERIOD_CUSTOM)
 				continue;
 
-			start_hour = atoi(variables[x]);
+			start_hour = atoi(value);
 			timeperiod_type = TIMEPERIOD_CUSTOM;
 			compute_time_from_parts = TRUE;
 		}
 
 
 		/* we found time argument */
-		else if (!strcmp(variables[x], "emon")) {
-			x++;
-			if (variables[x] == NULL) {
+		else if (!strcmp(key, "emon")) {
+			if (value == NULL) {
 				error = TRUE;
 				break;
 			}
@@ -1156,15 +1154,14 @@ int process_cgivars(void) {
 			if (timeperiod_type != TIMEPERIOD_CUSTOM)
 				continue;
 
-			end_month = atoi(variables[x]);
+			end_month = atoi(value);
 			timeperiod_type = TIMEPERIOD_CUSTOM;
 			compute_time_from_parts = TRUE;
 		}
 
 		/* we found time argument */
-		else if (!strcmp(variables[x], "eday")) {
-			x++;
-			if (variables[x] == NULL) {
+		else if (!strcmp(key, "eday")) {
+			if (value == NULL) {
 				error = TRUE;
 				break;
 			}
@@ -1172,15 +1169,14 @@ int process_cgivars(void) {
 			if (timeperiod_type != TIMEPERIOD_CUSTOM)
 				continue;
 
-			end_day = atoi(variables[x]);
+			end_day = atoi(value);
 			timeperiod_type = TIMEPERIOD_CUSTOM;
 			compute_time_from_parts = TRUE;
 		}
 
 		/* we found time argument */
-		else if (!strcmp(variables[x], "eyear")) {
-			x++;
-			if (variables[x] == NULL) {
+		else if (!strcmp(key, "eyear")) {
+			if (value == NULL) {
 				error = TRUE;
 				break;
 			}
@@ -1188,15 +1184,14 @@ int process_cgivars(void) {
 			if (timeperiod_type != TIMEPERIOD_CUSTOM)
 				continue;
 
-			end_year = atoi(variables[x]);
+			end_year = atoi(value);
 			timeperiod_type = TIMEPERIOD_CUSTOM;
 			compute_time_from_parts = TRUE;
 		}
 
 		/* we found time argument */
-		else if (!strcmp(variables[x], "emin")) {
-			x++;
-			if (variables[x] == NULL) {
+		else if (!strcmp(key, "emin")) {
+			if (value == NULL) {
 				error = TRUE;
 				break;
 			}
@@ -1204,15 +1199,14 @@ int process_cgivars(void) {
 			if (timeperiod_type != TIMEPERIOD_CUSTOM)
 				continue;
 
-			end_minute = atoi(variables[x]);
+			end_minute = atoi(value);
 			timeperiod_type = TIMEPERIOD_CUSTOM;
 			compute_time_from_parts = TRUE;
 		}
 
 		/* we found time argument */
-		else if (!strcmp(variables[x], "esec")) {
-			x++;
-			if (variables[x] == NULL) {
+		else if (!strcmp(key, "esec")) {
+			if (value == NULL) {
 				error = TRUE;
 				break;
 			}
@@ -1220,15 +1214,14 @@ int process_cgivars(void) {
 			if (timeperiod_type != TIMEPERIOD_CUSTOM)
 				continue;
 
-			end_second = atoi(variables[x]);
+			end_second = atoi(value);
 			timeperiod_type = TIMEPERIOD_CUSTOM;
 			compute_time_from_parts = TRUE;
 		}
 
 		/* we found time argument */
-		else if (!strcmp(variables[x], "ehour")) {
-			x++;
-			if (variables[x] == NULL) {
+		else if (!strcmp(key, "ehour")) {
+			if (value == NULL) {
 				error = TRUE;
 				break;
 			}
@@ -1236,104 +1229,98 @@ int process_cgivars(void) {
 			if (timeperiod_type != TIMEPERIOD_CUSTOM)
 				continue;
 
-			end_hour = atoi(variables[x]);
+			end_hour = atoi(value);
 			timeperiod_type = TIMEPERIOD_CUSTOM;
 			compute_time_from_parts = TRUE;
 		}
 
 		/* we found the embed option */
-		else if (!strcmp(variables[x], "embedded"))
+		else if (!strcmp(key, "embedded"))
 			embedded = TRUE;
 
 		/* we found the noheader option */
-		else if (!strcmp(variables[x], "noheader"))
+		else if (!strcmp(key, "noheader"))
 			display_header = FALSE;
 
 		/* we found the nodaemoncheck option */
-		else if (!strcmp(variables[x], "nodaemoncheck"))
+		else if (!strcmp(key, "nodaemoncheck"))
 			daemon_check = FALSE;
 
 		/* we found the input option */
-		else if (!strcmp(variables[x], "input")) {
-			x++;
-			if (variables[x] == NULL) {
+		else if (!strcmp(key, "input")) {
+			if (value == NULL) {
 				error = TRUE;
 				break;
 			}
 
-			if (!strcmp(variables[x], "gethost"))
+			if (!strcmp(value, "gethost"))
 				input_type = GET_INPUT_HOST_TARGET;
-			else if (!strcmp(variables[x], "getservice"))
+			else if (!strcmp(value, "getservice"))
 				input_type = GET_INPUT_SERVICE_TARGET;
-			else if (!strcmp(variables[x], "getoptions"))
+			else if (!strcmp(value, "getoptions"))
 				input_type = GET_INPUT_OPTIONS;
 			else
 				input_type = GET_INPUT_TARGET_TYPE;
 		}
 
 		/* we found the graph states option */
-		else if (!strcmp(variables[x], "graphevents")) {
-			x++;
-			if (variables[x] == NULL) {
+		else if (!strcmp(key, "graphevents")) {
+			if (value == NULL) {
 				error = TRUE;
 				break;
 			}
 
-			graph_events = atoi(variables[x]);
+			graph_events = atoi(value);
 		}
 
 		/* we found the graph state types option */
-		else if (!strcmp(variables[x], "graphstatetypes")) {
-			x++;
-			if (variables[x] == NULL) {
+		else if (!strcmp(key, "graphstatetypes")) {
+			if (value == NULL) {
 				error = TRUE;
 				break;
 			}
 
-			graph_statetypes = atoi(variables[x]);
+			graph_statetypes = atoi(value);
 		}
 
 		/* we found the breakdown option */
-		else if (!strcmp(variables[x], "breakdown")) {
-			x++;
-			if (variables[x] == NULL) {
+		else if (!strcmp(key, "breakdown")) {
+			if (value == NULL) {
 				error = TRUE;
 				break;
 			}
 
-			if (!strcmp(variables[x], "monthly"))
+			if (!strcmp(value, "monthly"))
 				breakdown_type = BREAKDOWN_MONTHLY;
-			else if (!strcmp(variables[x], "dayofmonth"))
+			else if (!strcmp(value, "dayofmonth"))
 				breakdown_type = BREAKDOWN_DAY_OF_MONTH;
-			else if (!strcmp(variables[x], "dayofweek"))
+			else if (!strcmp(value, "dayofweek"))
 				breakdown_type = BREAKDOWN_DAY_OF_WEEK;
 			else
 				breakdown_type = BREAKDOWN_HOURLY;
 		}
 
 		/* we found the assume state retention option */
-		else if (!strcmp(variables[x], "assumestateretention")) {
-			x++;
-			if (variables[x] == NULL) {
+		else if (!strcmp(key, "assumestateretention")) {
+			if (value == NULL) {
 				error = TRUE;
 				break;
 			}
 
-			if (!strcmp(variables[x], "yes"))
+			if (!strcmp(value, "yes"))
 				assume_state_retention = TRUE;
 			else
 				assume_state_retention = FALSE;
 		}
 
 		/* we found the initial states logged option */
-		else if (!strcmp(variables[x], "initialstateslogged")) {
-			x++;
-			if (variables[x] == NULL) {
+		else if (!strcmp(key, "initialstateslogged")) {
+			if (value == NULL) {
 				error = TRUE;
 				break;
 			}
 
-			if (!strcmp(variables[x], "yes"))
+			if (!strcmp(value, "yes"))
 				initial_states_logged = TRUE;
 			else
 				initial_states_logged = FALSE;
@@ -1341,14 +1328,13 @@ int process_cgivars(void) {
 		}
 
 		/* we found the new states only option */
-		else if (!strcmp(variables[x], "newstatesonly")) {
-			x++;
-			if (variables[x] == NULL) {
+		else if (!strcmp(key, "newstatesonly")) {
+			if (value == NULL) {
 				error = TRUE;
 				break;
 			}
 
-			if (!strcmp(variables[x], "yes"))
+			if (!strcmp(value, "yes"))
 				new_states_only = TRUE;
 			else
 				new_states_only = FALSE;
